@@ -1,5 +1,5 @@
 /*
- * Sylpheed -- regexp pattern matching utilities
+ * Claws Mail -- regexp pattern matching utilities
  * Copyright (C) 2001 Thomas Link, Hiroyuki Yamamoto
  *                    Modified by Melvin Hadasht.
  *
@@ -35,6 +35,19 @@
 #include "string_match.h"
 #include "utils.h"
 
+int string_match_precompile (gchar *rexp, regex_t *preg, int cflags)
+{
+	int problem = 0;
+
+	cm_return_val_if_fail(rexp, -1);
+	cm_return_val_if_fail(*rexp, -1);
+
+	problem = regcomp(preg, rexp, cflags);  
+	
+	return problem;
+}
+
+
 gchar *string_remove_match(gchar *buf, gint buflen, gchar * txt, regex_t *preg)
 {
 	regmatch_t match;
