@@ -6,10 +6,9 @@
 #define __TLDS_H__
 
 static const gchar *toplvl_domains [] = {
-	/* Version 2022101600, Last Updated Sun Oct 16 07:07:02 2022 UTC */
+	/* Version 2023111900, Last Updated Sun Nov 19 07:07:02 2023 UTC */
 	"aaa",
 	"aarp",
-	"abarth",
 	"abb",
 	"abbott",
 	"abbvie",
@@ -25,7 +24,6 @@ static const gchar *toplvl_domains [] = {
 	"aco",
 	"actor",
 	"ad",
-	"adac",
 	"ads",
 	"adult",
 	"ae",
@@ -45,7 +43,6 @@ static const gchar *toplvl_domains [] = {
 	"airtel",
 	"akdn",
 	"al",
-	"alfaromeo",
 	"alibaba",
 	"alipay",
 	"allfinanz",
@@ -224,7 +221,6 @@ static const gchar *toplvl_domains [] = {
 	"cba",
 	"cbn",
 	"cbre",
-	"cbs",
 	"cc",
 	"cd",
 	"center",
@@ -253,7 +249,6 @@ static const gchar *toplvl_domains [] = {
 	"citi",
 	"citic",
 	"city",
-	"cityeats",
 	"ck",
 	"cl",
 	"claims",
@@ -287,7 +282,6 @@ static const gchar *toplvl_domains [] = {
 	"contact",
 	"contractors",
 	"cooking",
-	"cookingchannel",
 	"cool",
 	"coop",
 	"corsica",
@@ -393,7 +387,6 @@ static const gchar *toplvl_domains [] = {
 	"esq",
 	"estate",
 	"et",
-	"etisalat",
 	"eu",
 	"eurovision",
 	"eus",
@@ -419,7 +412,6 @@ static const gchar *toplvl_domains [] = {
 	"ferrari",
 	"ferrero",
 	"fi",
-	"fiat",
 	"fidelity",
 	"fido",
 	"film",
@@ -445,7 +437,6 @@ static const gchar *toplvl_domains [] = {
 	"fo",
 	"foo",
 	"food",
-	"foodnetwork",
 	"football",
 	"ford",
 	"forex",
@@ -458,7 +449,6 @@ static const gchar *toplvl_domains [] = {
 	"fresenius",
 	"frl",
 	"frogans",
-	"frontdoor",
 	"frontier",
 	"ftr",
 	"fujitsu",
@@ -551,7 +541,6 @@ static const gchar *toplvl_domains [] = {
 	"helsinki",
 	"here",
 	"hermes",
-	"hgtv",
 	"hiphop",
 	"hisamitsu",
 	"hitachi",
@@ -573,7 +562,6 @@ static const gchar *toplvl_domains [] = {
 	"host",
 	"hosting",
 	"hot",
-	"hoteles",
 	"hotels",
 	"hotmail",
 	"house",
@@ -661,7 +649,6 @@ static const gchar *toplvl_domains [] = {
 	"kia",
 	"kids",
 	"kim",
-	"kinder",
 	"kindle",
 	"kitchen",
 	"kiwi",
@@ -686,7 +673,6 @@ static const gchar *toplvl_domains [] = {
 	"lamborghini",
 	"lamer",
 	"lancaster",
-	"lancia",
 	"land",
 	"landrover",
 	"lanxess",
@@ -717,7 +703,6 @@ static const gchar *toplvl_domains [] = {
 	"limited",
 	"limo",
 	"lincoln",
-	"linde",
 	"link",
 	"lipsy",
 	"live",
@@ -729,7 +714,6 @@ static const gchar *toplvl_domains [] = {
 	"loans",
 	"locker",
 	"locus",
-	"loft",
 	"lol",
 	"london",
 	"lotte",
@@ -749,7 +733,6 @@ static const gchar *toplvl_domains [] = {
 	"lv",
 	"ly",
 	"ma",
-	"macys",
 	"madrid",
 	"maif",
 	"maison",
@@ -763,7 +746,6 @@ static const gchar *toplvl_domains [] = {
 	"markets",
 	"marriott",
 	"marshalls",
-	"maserati",
 	"mattel",
 	"mba",
 	"mc",
@@ -823,7 +805,6 @@ static const gchar *toplvl_domains [] = {
 	"mu",
 	"museum",
 	"music",
-	"mutual",
 	"mv",
 	"mw",
 	"mx",
@@ -864,7 +845,6 @@ static const gchar *toplvl_domains [] = {
 	"nl",
 	"no",
 	"nokia",
-	"northwesternmutual",
 	"norton",
 	"now",
 	"nowruz",
@@ -910,7 +890,6 @@ static const gchar *toplvl_domains [] = {
 	"partners",
 	"parts",
 	"party",
-	"passagens",
 	"pay",
 	"pccw",
 	"pe",
@@ -1011,7 +990,6 @@ static const gchar *toplvl_domains [] = {
 	"rio",
 	"rip",
 	"ro",
-	"rocher",
 	"rocks",
 	"rodeo",
 	"rogers",
@@ -1066,7 +1044,6 @@ static const gchar *toplvl_domains [] = {
 	"select",
 	"sener",
 	"services",
-	"ses",
 	"seven",
 	"sew",
 	"sex",
@@ -1085,7 +1062,6 @@ static const gchar *toplvl_domains [] = {
 	"shopping",
 	"shouji",
 	"show",
-	"showtime",
 	"si",
 	"silk",
 	"sina",
@@ -1183,7 +1159,6 @@ static const gchar *toplvl_domains [] = {
 	"tiaa",
 	"tickets",
 	"tienda",
-	"tiffany",
 	"tips",
 	"tires",
 	"tirol",
@@ -1213,7 +1188,6 @@ static const gchar *toplvl_domains [] = {
 	"trading",
 	"training",
 	"travel",
-	"travelchannel",
 	"travelers",
 	"travelersinsurance",
 	"trust",
@@ -1275,7 +1249,6 @@ static const gchar *toplvl_domains [] = {
 	"voto",
 	"voyage",
 	"vu",
-	"vuelos",
 	"wales",
 	"walmart",
 	"walter",
