@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2020 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2022 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,6 +16,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "config.h"
 #include "defs.h"
 
 #include <glib.h>
@@ -108,9 +109,6 @@ static void foldersel_cancel		(GtkButton	*button,
 static void foldersel_new_folder	(GtkButton	*button,
 					 gpointer	 data);
 
-static void foldersel_entry_activated	(GtkEntry	*entry,
-					 gpointer	 data);
-
 static void foldersel_tree_activated	(GtkTreeView		*treeview,
 					 GtkTreePath		*path,
 					 GtkTreeViewColumn	*column,
@@ -217,10 +215,13 @@ static gboolean foldersel_search_name_func(GtkTreeModel *model, gint column,
 		gtk_tree_model_get(model, iter, column, &store_string, -1);
 	}
 
-	if (!store_string || !key)
+	if (!store_string)
 		return FALSE;
 
-	retval = (strcasestr(store_string, key) == NULL);
+	if (!key)
+		retval = FALSE;
+	else
+		retval = (strcasestr(store_string, key) == NULL);
 
 	g_free(store_string);
 
@@ -342,13 +343,11 @@ static void foldersel_create(const gchar *title)
 	statusbar_cid = gtk_statusbar_get_context_id(
 		        GTK_STATUSBAR(statusbar), "Select Folder Dialog" );
 	gtk_box_pack_start(GTK_BOX(vbox), statusbar, FALSE, FALSE, 0);
-	g_signal_connect(G_OBJECT(statusbar), "activate",
-			 G_CALLBACK(foldersel_entry_activated), NULL);
 
 	gtkut_stock_button_set_create(&confirm_area,
-				      &new_button,    _("_New"),
-				      &cancel_button, _("_Cancel"),
-				      &ok_button,     _("_OK"));
+				      &new_button,    NULL, _("_New"),
+				      &cancel_button, NULL, _("_Cancel"),
+				      &ok_button,     NULL, _("_OK"));
 
 	gtk_box_pack_end(GTK_BOX(vbox), confirm_area, FALSE, FALSE, 0);
 	gtk_widget_grab_default(ok_button);
@@ -628,11 +627,6 @@ static void foldersel_new_folder(GtkButton *button, gpointer data)
 	folder_write_list();
 }
 
-static void foldersel_entry_activated(GtkEntry *entry, gpointer data)
-{
-	gtk_button_clicked(GTK_BUTTON(ok_button));
-}
-
 static void foldersel_tree_activated(GtkTreeView *treeview, GtkTreePath *path,
 				     GtkTreeViewColumn *column, gpointer data)
 {
