@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2022 the Claws Mail team and Hiroyuki Yamamoto
+ * Copyright (C) 1999-2023 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -161,7 +161,7 @@ static GtkWidget *about_create_child_page_info(void)
 				NULL);
 #ifdef GENERIC_UMPC
 	ADD_TEXT("\n\n");
-	ADD_TEXT(_("Copyright (C) 1999-2022\nThe Claws Mail Team\n"
+	ADD_TEXT(_("Copyright (C) 1999-2023\nThe Claws Mail Team\n"
 				"and Hiroyuki Yamamoto"));
 #endif
 	ADD_TEXT("\n\n");
@@ -760,6 +760,11 @@ static void about_update_stats(void)
 					session_stats.received);
 		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
 				"indented-list-item", "bold", NULL);
+		if (session_stats.spam > 0) {
+			g_snprintf(buf, sizeof(buf), _("Spam messages: %d\n"), session_stats.spam);
+			gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter, buf, -1,
+								 "indented-list-item", NULL);
+		}
 
 		gtk_text_buffer_insert(stats_text_buffer, &iter, "\n", 1);
 		gtk_text_buffer_insert_with_tags_by_name(stats_text_buffer, &iter,
@@ -868,7 +873,7 @@ static void about_create(void)
 	gtk_container_add(GTK_CONTAINER(grid2), button);
 #ifndef GENERIC_UMPC
 	label = gtk_label_new
-		(_("Copyright (C) 1999-2022\nThe Claws Mail Team\n"
+		(_("Copyright (C) 1999-2023\nThe Claws Mail Team\n"
 		 "and Hiroyuki Yamamoto"));
 	gtk_label_set_selectable(GTK_LABEL(label), TRUE);
 	gtk_label_set_justify(GTK_LABEL(label), GTK_JUSTIFY_CENTER);
