@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2016-2019 the Claws Mail team and Andrej Kacian
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 2016-2021 the Claws Mail team and Andrej Kacian
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -70,19 +70,19 @@ static void ok_button_clicked(GtkButton *button, gpointer user_data)
 		return;
 	}
 
-	/* If there is an existing master passphrase, check for its correctness
+	/* If there is an existing primary passphrase, check for its correctness
 	 * in entry_old. */
-	if (master_passphrase_is_set()
+	if (primary_passphrase_is_set()
 			&& ((old = gtk_entry_get_text(GTK_ENTRY(ctx->entry_old))) == NULL
-				|| strlen(old) == 0 || !master_passphrase_is_correct(old))) {
+				|| strlen(old) == 0 || !primary_passphrase_is_correct(old))) {
 		debug_print("old passphrase incorrect\n");
-		alertpanel_warning(_("Incorrect old master passphrase entered, try again."));
+		alertpanel_warning(_("Incorrect old primary passphrase entered, try again."));
 		gtk_entry_set_text(GTK_ENTRY(ctx->entry_old), "");
 		gtk_widget_grab_focus(ctx->entry_old);
 		return;
 	}
 
-	master_passphrase_change(old, new1);
+	primary_passphrase_change(old, new1);
 
 	ctx->done = TRUE;
 	gtk_widget_destroy(ctx->dialog);
@@ -104,7 +104,7 @@ static void dialog_destroy(GtkWidget *widget, gpointer user_data)
 	ctx->dialog = NULL;
 }
 
-void master_passphrase_change_dialog()
+void primary_passphrase_change_dialog()
 {
 	static PangoFontDescription *font_desc;
 	GtkWidget *dialog;
@@ -112,7 +112,6 @@ void master_passphrase_change_dialog()
 	GtkWidget *icon, *table, *label;
 	GtkWidget *msg_title;
 	GtkWidget *entry_old, *entry_new1, *entry_new2;
-	GtkWidget *confirm_area;
 	GtkWidget *ok_button, *cancel_button;
 	struct _ctx *ctx;
 
@@ -141,7 +140,7 @@ void master_passphrase_change_dialog()
 	gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
 	gtk_widget_show(vbox);
 
-	msg_title = gtk_label_new(_("Changing master passphrase"));
+	msg_title = gtk_label_new(_("Changing primary passphrase"));
 	gtk_label_set_xalign(GTK_LABEL(msg_title), 0.0);
 	gtk_label_set_justify(GTK_LABEL(msg_title), GTK_JUSTIFY_LEFT);
 	gtk_label_set_use_markup (GTK_LABEL (msg_title), TRUE);
@@ -162,7 +161,7 @@ void master_passphrase_change_dialog()
 		gtk_widget_override_font(msg_title, font_desc);
 
 	label = gtk_label_new(
-        _("If a master passphrase is currently active, it\n"
+        _("If a primary passphrase is currently active, it\n"
         "needs to be entered.")
 	);
 	gtk_label_set_xalign(GTK_LABEL(label), 0.0);
@@ -209,20 +208,14 @@ void master_passphrase_change_dialog()
 
 	gtk_box_pack_start(GTK_BOX(vbox), table, FALSE, FALSE, 0);
 
-	/* Dialog buttons */
-	gtkut_stock_button_set_create(&confirm_area,
-			&cancel_button, _("_Cancel"),
-			&ok_button, _("_OK"),
-			NULL, NULL);
-
-	gtk_box_pack_end(GTK_BOX(gtk_dialog_get_action_area(GTK_DIALOG(dialog))),
-			confirm_area, FALSE, FALSE, 0);
-	gtk_container_set_border_width(GTK_CONTAINER(confirm_area), 5);
-
+	cancel_button = gtk_dialog_add_button(GTK_DIALOG(dialog), _("_Cancel"),
+					      GTK_RESPONSE_NONE);
+	ok_button = gtk_dialog_add_button(GTK_DIALOG(dialog),_("_OK"),
+					  GTK_RESPONSE_NONE);
 	gtk_widget_grab_default(ok_button);
 
-	/* If no master passphrase is set, disable the "old passphrase" entry */
-	if (!master_passphrase_is_set())
+	/* If no primary passphrase is set, disable the "old passphrase" entry */
+	if (!primary_passphrase_is_set())
 		gtk_widget_set_sensitive(entry_old, FALSE);
 
 	g_signal_connect(G_OBJECT(entry_old), "activate",
