@@ -1,7 +1,7 @@
 /* vim: set textwidth=80 tabstop=4: */
 
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2018 Michael Rasmussen and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -51,10 +51,10 @@ struct ArchivePage {
     GtkWidget*  unlink_files;
 };
 
-void archiver_gtk_show(void);
-void archiver_gtk_done(struct ArchivePage* page, GtkWidget* widget);
+void archiver_gtk_show();
+void archiver_gtk_done();
 void set_progress_file_label(const gchar* file);
 void set_progress_print_all(guint fraction, guint total, guint step);
-void stop_archiving(void);
+void stop_archiving();
 
 #endif
