@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2024 Michael Rasmussen and the Claws Mail Team
+ * Copyright (C) 1999-2018 Michael Rasmussen and the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,15 +27,12 @@
 
 #include "libarchive_archive.h"
 
-#ifndef DEBUG_ARCHIVE
+#ifndef _TEST
 #	include "archiver.h"
 #	include "utils.h"
 #	include "mainwindow.h"
 #   include "folder.h"
 #endif
-#ifdef DEBUG_ARCHIVE
-#include "procmsg.h"
-#endif
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -47,6 +44,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
+#include <dirent.h>
 #include <libgen.h>
 
 #define READ_BLOCK_SIZE 10240
@@ -60,7 +58,7 @@ static GSList* msg_trash_list = NULL;
 static GSList* file_list = NULL;
 static gboolean stop_action = FALSE;
 
-#ifdef DEBUG_ARCHIVE
+#ifdef _TEST
 static int permissions = 0;
 #endif
 
@@ -244,7 +242,7 @@ static void archive_free_file_info(struct file_info* file) {
 	file = NULL;
 }
 
-void stop_archiving(void) {
+void stop_archiving() {
 	debug_print("stop action set to true\n");
 	stop_action = TRUE;
 }
@@ -270,7 +268,7 @@ void archive_free_file_list(gboolean md5, gboolean rename) {
 			debug_print("unlinking %s\n", path);
 			if (g_unlink(path) < 0)
                                 FILE_OP_ERROR(path, "g_unlink");
-                        g_free(path);
+			g_free(path);
 		}
 		archive_free_file_info(file);
 		file_list->data = NULL;
@@ -313,7 +311,7 @@ static gchar* get_full_path(struct file_info* file) {
 	return path;
 }
 
-#ifdef DEBUG_ARCHIVE
+#ifdef _TEST
 static gchar* strip_leading_slash(gchar* path) {
 	gchar* stripped = path;
 	gchar* result = NULL;
@@ -358,7 +356,7 @@ void archive_add_file(gchar* path) {
 
 	g_return_if_fail(path != NULL);
 
-#ifndef DEBUG_ARCHIVE
+#ifndef _TEST
 	debug_print("add %s to list\n", path);
 #endif
 	filename = g_strrstr_len(path, strlen(path), "/");
@@ -377,16 +375,16 @@ GSList* archive_get_file_list() {
 	return file_list;
 }
 
-#ifdef DEBUG_ARCHIVE
+#ifdef _TEST
 const gchar* archive_extract(const char* archive_name, int flags) {
 	struct archive* in;
 	struct archive* out;
 	struct archive_entry* entry;
 	int res = ARCHIVE_OK;
 	gchar* buf = NULL;
-	const char* result = NULL;
+	const char* result == NULL;
 
-	g_return_val_if_fail(archive_name != NULL, NULL);
+	g_return_val_if_fail(archive_name != NULL, ARCHIVE_FATAL);
 
 	fprintf(stdout, "%s: extracting\n", archive_name);
 	in = archive_read_new();
@@ -455,7 +453,7 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 			COMPRESS_METHOD method, ARCHIVE_FORMAT format) {
 	struct archive* arch;
 
-#ifndef DEBUG_ARCHIVE
+#ifndef _TEST
 	gint num = 0;
 	gint total = g_slist_length (files);
 #endif
@@ -573,7 +571,7 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 		struct file_info* file;
 		gchar* filename = NULL;
 
-#ifndef DEBUG_ARCHIVE
+#ifndef _TEST
 		set_progress_print_all(num++, total, 30);
 #endif
 		file = (struct file_info *) files->data;
@@ -583,7 +581,7 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 		/* libarchive will crash if instructed to add archive to it self */
 		if (g_utf8_collate(archive_name, filename) == 0) {
 			g_warning("%s: not dumping to '%s'", archive_name, filename);
-#ifndef DEBUG_ARCHIVE
+#ifndef _TEST
 			debug_print("%s: not dumping to '%s'\n", archive_name, filename);
 #endif
 		}
@@ -596,7 +594,7 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 			int fd;
 			gchar* msg = NULL;
 
-#ifndef DEBUG_ARCHIVE
+#ifndef _TEST
 			debug_print("Adding: %s\n", filename);
 			msg = g_strdup_printf("%s", filename);
 			set_progress_file_label(msg);
@@ -651,7 +649,7 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 		g_free(filename);
 		files = g_slist_next(files);
 	}
-#ifndef DEBUG_ARCHIVE
+#ifndef _TEST
 	if (stop_action)
 		unlink(archive_name);
 	stop_action = FALSE;
@@ -665,35 +663,32 @@ const gchar* archive_create(const char* archive_name, GSList* files,
 	return NULL;
 }
 
-#ifdef DEBUG_ARCHIVE
+#ifdef _TEST
 void archive_scan_folder(const char* dir) {
 	GStatBuf st;
-	GDir* root;
-	const gchar* ent;
+	DIR* root;
+	struct dirent* ent;
 	gchar cwd[PATH_MAX];
 	gchar path[PATH_MAX];
-	GError *error = NULL;
-
+	
 	getcwd(cwd, PATH_MAX);
 
 	if (g_stat(dir, &st) == -1)
 		return;
 	if (! S_ISDIR(st.st_mode))
 		return;
-	if (!(root = g_dir_open(dir, 0, &error))) {
-		debug_print("opening '%s' failed: %d (%s)\n", dir, error->code, error->message);
+	if (!(root = opendir(dir)))
 		return;
-	}
 	chdir(dir);
 
-	while ((ent = g_dir_read_name(root)) != NULL) {
-		if (strcmp(".", ent) == 0 || strcmp("..", ent) == 0)
+	while ((ent = readdir(root)) != NULL) {
+		if (strcmp(".", ent->d_name) == 0 || strcmp("..", ent->d_name) == 0)
 			continue;
-		if (g_stat(ent, &st) == -1) {
-			FILE_OP_ERROR(ent, "g_stat");
+		if (g_stat(ent->d_name, &st) == -1) {
+			FILE_OP_ERROR(filename, "g_stat");
 			continue;
 		}
-		sprintf(path, "%s/%s", dir, ent);
+		sprintf(path, "%s/%s", dir, ent->d_name);
 		if (S_ISREG(st.st_mode) || S_ISLNK(st.st_mode)) {
 			archive_add_file(path);
 		}
@@ -702,7 +697,7 @@ void archive_scan_folder(const char* dir) {
 		}
 	}
 	chdir(cwd);
-	g_dir_close(root);
+	closedir(root);
 }
 
 int main(int argc, char** argv) {
@@ -748,7 +743,7 @@ int main(int argc, char** argv) {
 	
 	while (*argv) {
 		archive_scan_folder(*argv++);
-		res = archive_create(archive, file_list, GZIP, TAR);
+		res = archive_create(archive, file_list);
 		if (res != ARCHIVE_OK) {
 			fprintf(stderr, "%s: Creating archive failed\n", archive);
 			return EXIT_FAILURE;
