@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 the Claws Mail Team
+ * Copyright (C) 1999-2023 the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -125,6 +125,11 @@ static void dillo_show_mimepart(MimeViewer *_viewer,
 		g_free(viewer->filename);
 	}
 
+	if (!GDK_IS_X11_DISPLAY(gdk_display_get_default())) {
+		debug_print("dillo viewer only works on X11\n");
+		return;
+	}
+
 	viewer->filename = procmime_get_tmp_file_name(partinfo);
 	
 	if (!(procmime_get_part(viewer->filename, partinfo) < 0)) {
