@@ -1,5 +1,5 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2015 the Claws Mail Team
  * Copyright (C) 2014-2015 Charles Lehner
  *
@@ -18,6 +18,8 @@
  * 
  */
 
+#include "config.h"
+
 #include <glib.h>
 #include <glib/gi18n.h>
 
