@@ -1,7 +1,7 @@
 /*
  * Notification plugin for Claws-Mail
- * Claws Mail -- A GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2019 Holger Berndt and the Claws Mail team
+ * Claws Mail -- A GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 2005-2021 the Claws Mail team and Holger Berndt
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -394,8 +394,6 @@ static void notify_hotkeys_enable_set_sensitivity(GtkToggleButton*, gpointer);
 #endif /* NOTIFICATION_HOTKEYS */
 
 
-static gint conv_color_to_int(GdkColor*);
-
 void notify_gtk_init(void)
 {
 	static gchar *path[3];
@@ -583,7 +581,7 @@ void notify_save_config(void)
 
 	if (prefs_write_param(notify_param, pfile->fp) < 0) {
 		debug_print("failed!\n");
-		g_warning("Notification Plugin: Failed to write plugin configuration "
+		g_warning("notification plugin: failed to write plugin configuration "
 						"to file");
 		prefs_file_close_revert(pfile);
 		return;
@@ -794,7 +792,7 @@ static void notify_create_banner_page(PrefsPage *page, GtkWindow *window,
 	gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
 
-	slider = gtk_hscale_new_with_range(10., 70., 10.);
+	slider = gtk_scale_new_with_range(GTK_ORIENTATION_HORIZONTAL, 10., 70., 10.);
 	gtk_scale_set_digits(GTK_SCALE(slider), 0);
 	gtk_widget_get_preferred_size(combo, &requisition, NULL);
 	gtk_widget_set_size_request(slider, requisition.width, -1);
@@ -920,9 +918,7 @@ static void notify_create_banner_page(PrefsPage *page, GtkWindow *window,
 	label = gtk_label_new(_("Foreground"));
 	gtk_box_pack_start(GTK_BOX(chbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
-	color_sel = gtk_color_button_new();
-	gtk_color_button_set_rgba(GTK_COLOR_BUTTON(color_sel),
-			&notify_config.banner_color_fg);
+	color_sel = gtk_color_button_new_with_rgba(&notify_config.banner_color_fg);
 	gtk_color_button_set_title(GTK_COLOR_BUTTON(color_sel),_("Foreground color"));
 	gtk_box_pack_start(GTK_BOX(chbox), color_sel, FALSE, FALSE, 0);
 	gtk_widget_show(color_sel);
@@ -931,9 +927,7 @@ static void notify_create_banner_page(PrefsPage *page, GtkWindow *window,
 	label = gtk_label_new(_("Background"));
 	gtk_box_pack_start(GTK_BOX(chbox), label, FALSE, FALSE, 0);
 	gtk_widget_show(label);
-	color_sel = gtk_color_button_new();
-	gtk_color_button_set_rgba(GTK_COLOR_BUTTON(color_sel),
-			&notify_config.banner_color_bg);
+	color_sel = gtk_color_button_new_with_rgba(&notify_config.banner_color_bg);
 	gtk_color_button_set_title(GTK_COLOR_BUTTON(color_sel), _("Background color"));
 	gtk_box_pack_start(GTK_BOX(chbox), color_sel, FALSE, FALSE, 0);
 	gtk_widget_show(color_sel);
@@ -981,11 +975,10 @@ static void notify_save_banner(PrefsPage *page)
 	gtk_toggle_button_get_active
 	(GTK_TOGGLE_BUTTON(banner_page.banner_enable_colors));
 
-	/* Color dialogs are a bit more complicated */
-	gtk_color_button_get_rgba(GTK_COLOR_BUTTON(banner_page.banner_color_fg),
-			&notify_config.banner_color_fg);
-	gtk_color_button_get_rgba(GTK_COLOR_BUTTON(banner_page.banner_color_bg),
-			&notify_config.banner_color_bg);
+	gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(banner_page.banner_color_fg),
+				   &notify_config.banner_color_fg);
+	gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(banner_page.banner_color_bg),
+				   &notify_config.banner_color_bg);
 
 	notification_banner_destroy();
 	notification_update_banner();
@@ -1290,7 +1283,7 @@ static void notify_command_browse_cb(GtkWidget* widget, gpointer data)
 
 	utf8_filename = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
 	if (!utf8_filename) {
-		g_warning("notify_command_browse_cb(): failed to convert character set.");
+		g_warning("notify_command_browse_cb(): failed to convert character set");
 		utf8_filename = g_strdup(filename);
 	}
 	gtk_entry_set_text(GTK_ENTRY(dest), utf8_filename);
@@ -1924,19 +1917,3 @@ static void notify_hotkeys_enable_set_sensitivity(GtkToggleButton *button,
     gtk_widget_set_sensitive(hotkeys_page.hotkeys_cont_enable, active);
 }
 #endif /* hotkeys */
-
-
-/* This feels so wrong... */
-static gint conv_color_to_int(GdkColor *color)
-{
-	gint result;
-	guint red, green, blue;
-
-	red = (guint) ((gdouble)(color->red) /65535.*255.);
-	green = (guint) ((gdouble)(color->green) /65535.*255.);
-	blue = (guint) ((gdouble)(color->blue) /65535.*255.);
-
-	result = (gint) (blue | (green<<8)| (red<<16));
-
-	return result;
-}
