@@ -1,5 +1,5 @@
 /* Notification plugin for Claws Mail
- * Copyright (C) 2005-2019 Holger Berndt and the Claws Mail Team.
+ * Copyright (C) 2005-2022 Holger Berndt and the Claws Mail Team.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -547,8 +547,8 @@ static void app_exit_cb(MainWindow *mainwin, guint action, GtkWidget *widget)
 {
   if(prefs_common_get_prefs()->confirm_on_exit) {
     if(alertpanel(_("Exit"), _("Exit Claws Mail?"),
-		  _("_Cancel"), _("_OK"),
-		  NULL, ALERTFOCUS_FIRST) != G_ALERTALTERNATE) {
+		  NULL, _("_Cancel"), NULL, _("_OK"),
+		  NULL, NULL, ALERTFOCUS_FIRST) != G_ALERTALTERNATE) {
       return;
     }
     manage_window_focus_in(mainwin->window, NULL, NULL);
@@ -896,10 +896,10 @@ static gchar* notification_trayicon_popup_assemble_body(MsgInfo *msginfo)
 
       /* Make sure text is valid UTF8 */
       utf8_str = notification_validate_utf8_str(text);
-      g_free(text);
 
-      if(from) g_free(from);
-      if(subj) g_free(subj);
+      g_free(text);
+      g_free(from);
+      g_free(subj);
 	  if(foldname) g_free(foldname);
     }
     else if(popup.num_calendar) {
