@@ -1,5 +1,5 @@
-/* passphrase.c - GTK+ based passphrase callback
- * Copyright (C) 2001-2019 Werner Koch (dd9jn) and the Claws Mail team
+/* passphrase.c - GTK based passphrase callback
+ * Copyright (C) 2001-2022 Werner Koch (dd9jn) and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -32,7 +32,7 @@
 #include <string.h>
 #include <sys/types.h>
 #ifdef G_OS_WIN32
-#include <w32lib.h>
+#include <windows.h>
 #else
 #include <sys/mman.h>
 #endif
@@ -119,9 +119,9 @@ passphrase_mbox(const gchar *uid_hint, const gchar *pass_hint, gint prev_bad, gi
     gtk_widget_grab_focus(pass_entry);
 
     gtkut_stock_button_set_create(&confirm_box, 
-				  &cancel_button, _("_Cancel"),
-		    		  &ok_button, _("_OK"),
-				  NULL, NULL);
+				  &cancel_button, NULL, _("_Cancel"),
+		    		  &ok_button, NULL, _("_OK"),
+				  NULL, NULL, NULL);
 
     gtk_box_pack_end(GTK_BOX(vbox), confirm_box, FALSE, FALSE, 0);
     gtk_widget_grab_default(ok_button);
@@ -256,23 +256,18 @@ create_description(const gchar *uid_hint, gint prev_bad, gint new_key)
     	*(strchr(my_uid, '>')) = ')';
 
     if (new_key == 1) {
-	    buf = g_strdup_printf (g_strconcat("<span weight=\"bold\" size=\"larger\">%s",
-					_("Please enter the passphrase for the new key:"),
-					"</span>\n\n%.*s\n", NULL),
-                           prev_bad ?
-                           _("Passphrases did not match.\n") : "",
+	    buf = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s%s</span>\n\n%.*s\n",
+                           prev_bad ? _("Passphrases did not match.\n") : "",
+                           _("Please enter the passphrase for the new key:"),
                            linelen (my_uid), my_uid);
     } else if (new_key == 2) {
-	    buf = g_strdup_printf (g_strconcat("<span weight=\"bold\" size=\"larger\">",
-				_("Please re-enter the passphrase for the new key:"),
-				"</span>\n\n%.*s\n", NULL),
+	    buf = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s</span>\n\n%.*s\n",
+                           _("Please re-enter the passphrase for the new key:"),
                            linelen (my_uid), my_uid);
     } else {
-	    buf = g_strdup_printf (g_strconcat("<span weight=\"bold\" size=\"larger\">%s",
-				_("Please enter the passphrase for:"),
-				"</span>\n\n%.*s\n", NULL),
-                           prev_bad ?
-                           _("Bad passphrase.\n") : "",
+	    buf = g_strdup_printf ("<span weight=\"bold\" size=\"larger\">%s%s</span>\n\n%.*s\n",
+                           prev_bad ? _("Bad passphrase.\n") : "",
+                           _("Please enter the passphrase for:"),
                            linelen (my_uid), my_uid);
     }
     g_free(my_uid);
