@@ -15,8 +15,6 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "clawsmailmodule.h"
-
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #include "claws-features.h"
@@ -25,6 +23,7 @@
 #include <glib.h>
 #include <glib/gi18n.h>
 
+#include "clawsmailmodule.h"
 #include "nodetype.h"
 #include "composewindowtype.h"
 #include "folderpropertiestype.h"
@@ -45,7 +44,6 @@
 #include "common/tags.h"
 #include "account.h"
 
-#include <glib.h>
 
 static PyObject *cm_module = NULL;
 
@@ -908,8 +906,8 @@ static struct PyModuleDef moduledef = {
   "This module can be used to access some of Claws Mail's data structures\n"
   "in order to extend or modify the user interface or automate repetitive tasks.\n"
   "\n"
-  "Whenever possible, the interface works with standard GTK+ widgets\n"
-  "via the PyGTK bindings, so you can refer to the GTK+ / PyGTK documentation\n"
+  "Whenever possible, the interface works with standard GTK widgets\n"
+  "via the PyGTK bindings, so you can refer to the GTK / PyGTK documentation\n"
   "to find out about all possible options.\n"
   "\n"
   "The interface to Claws Mail in this module is extended on a 'as-needed' basis.\n"
