@@ -1,6 +1,6 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2019 the Claws Mail team and Hiroyuki Yamamoto
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2022 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -282,14 +282,14 @@ static void prefs_summary_column_create(void)
 	gtk_widget_show(btn_vbox);
 	gtk_box_pack_start(GTK_BOX(hbox1), btn_vbox, FALSE, FALSE, 0);
 
-	add_btn = gtkut_stock_button("list-add");
+	add_btn = gtkut_stock_button("list-add", _("_Add"));
 	gtk_widget_show(add_btn);
 	gtk_box_pack_start(GTK_BOX(btn_vbox), add_btn, FALSE, TRUE, 0);
 
 	g_signal_connect(G_OBJECT(add_btn), "clicked",
 			 G_CALLBACK(prefs_summary_column_add), NULL);
 
-	remove_btn = gtkut_stock_button("list-remove");
+	remove_btn = gtkut_stock_button("list-remove", _("_Remove"));
 	gtk_widget_show(remove_btn);
 	gtk_box_pack_start(GTK_BOX(btn_vbox), remove_btn, FALSE, TRUE, 0);
 
@@ -323,11 +323,11 @@ static void prefs_summary_column_create(void)
 	gtk_widget_show(btn_vbox);
 	gtk_box_pack_start(GTK_BOX(hbox1), btn_vbox, FALSE, FALSE, 0);
 
-	up_btn = gtkut_stock_button("go-up");
+	up_btn = gtkut_stock_button("go-up", _("_Up"));
 	gtk_widget_show(up_btn);
 	gtk_box_pack_start(GTK_BOX(btn_vbox), up_btn, FALSE, TRUE, 0);
 
-	down_btn = gtkut_stock_button("go-down");
+	down_btn = gtkut_stock_button("go-down", _("_Down"));
 	gtk_widget_show(down_btn);
 	gtk_box_pack_start(GTK_BOX(btn_vbox), down_btn, FALSE, TRUE, 0);
 
@@ -352,9 +352,9 @@ static void prefs_summary_column_create(void)
 			 NULL);
 
 	gtkut_stock_button_set_create(&confirm_area,
-				      &cancel_btn, _("_Cancel"),
-				      &ok_btn, _("_OK"),
-				      NULL, NULL);
+				      &cancel_btn, NULL, _("_Cancel"),
+				      &ok_btn, NULL, _("_OK"),
+				      NULL, NULL, NULL);
 	gtk_widget_show(confirm_area);
 	gtk_box_pack_end(GTK_BOX(btn_hbox), confirm_area, FALSE, FALSE, 0);
 	gtk_widget_grab_default(ok_btn);
@@ -392,7 +392,7 @@ SummaryColumnState *prefs_summary_column_get_config(void)
 		pos = prefs_common.summary_col_pos[type];
 		if (pos < 0 || pos >= N_SUMMARY_COLS ||
 		    state[pos].type != -1) {
-			g_warning("Wrong column position");
+			g_warning("wrong column position");
 			prefs_summary_column_set_config(default_state);
 			return default_state;
 		}
