@@ -1,5 +1,5 @@
 /*
- * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Claws Mail -- a GTK based, lightweight, and fast e-mail client
  * Copyright (C) 1999-2021 the Claws Mail team and Hiroyuki Yamamoto
  *
  * This program is free software; you can redistribute it and/or modify
@@ -111,8 +111,10 @@ void privacy_free_privacydata(PrivacyData *privacydata)
 	system->free_privacydata(privacydata);
 }
 
-void privacy_free_signature_data(SignatureData *sig_data)
+void privacy_free_signature_data(gpointer data)
 {
+	SignatureData *sig_data = (SignatureData *)data;
+
 	cm_return_if_fail(sig_data != NULL);
 
 	g_free(sig_data->info_short);
